==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextPortion =
[
    [ "TextRange", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a41baae369214f95239b733253e58f582", null ],
    [ "XTolerantMultiPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aba3b343da2a7fe5ad3f96c9e189e70ef", null ],
    [ "XContentEnumerationAccess", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a90a21e619207817bbb341cae7416cd27", null ],
    [ "Bookmark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a228e862b92c0031094ad8c8f807f0af4", null ],
    [ "ControlCharacter", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#acaf6ca82bcb2c314991ad7ce3ce4146c", null ],
    [ "DocumentIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a2ac5a5bb4cbbe2516917e3cfec701a6e", null ],
    [ "Footnote", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aaaff65c416585f9b455ce4910074c7b8", null ],
    [ "InContentMetadata", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a93e1a5ed116ce273afa3234de3236617", null ],
    [ "IsCollapsed", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a6fe9fae130ae7a93713b5a27df357a87", null ],
    [ "IsStart", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a8b56270f2c7b718234757794dbcaa25f", null ],
    [ "ReferenceMark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a89d435b703fc9899b10c61073c9bf6e2", null ],
    [ "TextField", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aed8bc55aa27fd8de833aba872b24cbc6", null ],
    [ "TextPortionType", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a7ecd2de53df4ec8d3fffa94c2e80d651", null ]
];

==> libreoffice-fresh-sdk-25.8.4-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextPortion =
[
    [ "::com::sun::star::text::TextRange", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a41baae369214f95239b733253e58f582", null ],
    [ "::com::sun::star::beans::XTolerantMultiPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aba3b343da2a7fe5ad3f96c9e189e70ef", null ],
    [ "::com::sun::star::container::XContentEnumerationAccess", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a90a21e619207817bbb341cae7416cd27", null ],
    [ "Bookmark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a228e862b92c0031094ad8c8f807f0af4", null ],
    [ "ControlCharacter", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#acaf6ca82bcb2c314991ad7ce3ce4146c", null ],
    [ "DocumentIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a2ac5a5bb4cbbe2516917e3cfec701a6e", null ],
    [ "Footnote", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aaaff65c416585f9b455ce4910074c7b8", null ],
    [ "InContentMetadata", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a93e1a5ed116ce273afa3234de3236617", null ],
    [ "IsCollapsed", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a6fe9fae130ae7a93713b5a27df357a87", null ],
    [ "IsStart", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a8b56270f2c7b718234757794dbcaa25f", null ],
    [ "ReferenceMark", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a89d435b703fc9899b10c61073c9bf6e2", null ],
    [ "TextField", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#aed8bc55aa27fd8de833aba872b24cbc6", null ],
    [ "TextPortionType", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html#a7ecd2de53df4ec8d3fffa94c2e80d651", null ]
];
